@@ -3,7 +3,7 @@ REST Handler for WSGI application
 """
 
 __author__ = 'VMware, Inc.'
-__copyright__ = 'Copyright 2015-2019 VMware, Inc.  All rights reserved. -- VMware Confidential'  # pylint: disable=line-too-long
+__copyright__ = 'Copyright 2015-2020 VMware, Inc.  All rights reserved. -- VMware Confidential'  # pylint: disable=line-too-long
 
 import base64
 import collections
@@ -172,7 +172,8 @@ class MetadataStore(object):
                                             package_info.services):
                 self._process_service_info(service_id, service_info)
                 self.service_map[service_id] = {
-                    operation_id: self._create_operation_summary(operation_info)
+                    operation_id: self._create_operation_summary(operation_info,
+                                                                 service_id)
                         for operation_id, operation_info in six.iteritems(
                                                     service_info.operations)}
 
@@ -245,7 +246,20 @@ class MetadataStore(object):
 
         return header_variables, query_variables
 
-    def _create_operation_summary(self, operation_info):
+    def _translate_param_name(self, name):
+        """
+        Changes '__' to '-' in the parameter name. Before registering the
+        metadata dashes are changed because werkzeug doesn't allow dashes.
+
+        :type  name: :class:`str`
+        :param component_info: parameter name
+        :rtype: :class:`str`
+        :return: parameter name with dashes instead of '__'
+                 If there is nothing to change the provided name is returned
+        """
+        return name.replace('-', '__')
+
+    def _create_operation_summary(self, operation_info, service_id):
         """
         Generate a summary of the metamodel operation information.
 
@@ -265,36 +279,36 @@ class MetadataStore(object):
         success_response_code = None
         response_headers_map = None
         response_body_name = None
+        verb_info = None
 
         if RestAnnotations.REQUEST_MAPPING in operation_info.metadata.keys():
             # Create a map of value in PathVariable annotation to
             # canonical name of the parameter
             path_variables_map = {
-                param_info.metadata[RestAnnotations.PATH_VARIABLE].elements[
-                    RestAnnotations.VALUE_ELEMENT].string_value: param_name
+                self._translate_param_name(param_info.metadata[
+                    RestAnnotations.PATH_VARIABLE].elements[
+                    RestAnnotations.VALUE_ELEMENT].string_value): param_name
                 for param_name, param_info in six.iteritems(param_info_map)
                 if RestAnnotations.PATH_VARIABLE in param_info.metadata
             }
-
-        if RestAnnotations.VERB_GET in operation_info.metadata.keys():
-            verb_info = {RestAnnotations.VERB_GET:
-                         operation_info.metadata.get(RestAnnotations.VERB_GET)}
-        elif RestAnnotations.VERB_POST in operation_info.metadata.keys():
-            verb_info = {RestAnnotations.VERB_POST:
-                         operation_info.metadata.get(RestAnnotations.VERB_POST)}
-        elif RestAnnotations.VERB_PUT in operation_info.metadata.keys():
-            verb_info = {RestAnnotations.VERB_PUT:
-                         operation_info.metadata.get(RestAnnotations.VERB_PUT)}
-        elif RestAnnotations.VERB_PATCH in operation_info.metadata.keys():
-            verb_info = {RestAnnotations.VERB_PATCH:
-                         operation_info.metadata.get(
-                             RestAnnotations.VERB_PATCH)}
-        elif RestAnnotations.VERB_DELETE in operation_info.metadata.keys():
-            verb_info = {RestAnnotations.VERB_DELETE:
-                         operation_info.metadata.get(
-                            RestAnnotations.VERB_DELETE)}
-        else:
-            verb_info = None
+        elif service_id != 'com.vmware.cis.session':
+            if RestAnnotations.VERB_GET in operation_info.metadata.keys():
+                verb_info = {RestAnnotations.VERB_GET:
+                             operation_info.metadata.get(RestAnnotations.VERB_GET)}  # pylint: disable=line-too-long
+            elif RestAnnotations.VERB_POST in operation_info.metadata.keys():
+                verb_info = {RestAnnotations.VERB_POST:
+                             operation_info.metadata.get(RestAnnotations.VERB_POST)}  # pylint: disable=line-too-long
+            elif RestAnnotations.VERB_PUT in operation_info.metadata.keys():
+                verb_info = {RestAnnotations.VERB_PUT:
+                             operation_info.metadata.get(RestAnnotations.VERB_PUT)}  # pylint: disable=line-too-long
+            elif RestAnnotations.VERB_PATCH in operation_info.metadata.keys():
+                verb_info = {RestAnnotations.VERB_PATCH:
+                             operation_info.metadata.get(
+                                 RestAnnotations.VERB_PATCH)}
+            elif RestAnnotations.VERB_DELETE in operation_info.metadata.keys():
+                verb_info = {RestAnnotations.VERB_DELETE:
+                             operation_info.metadata.get(
+                                RestAnnotations.VERB_DELETE)}
 
         if verb_info is not None:
             header_variables_map, query_variables_map = \
