@@ -3,7 +3,7 @@ Authorization API Provider filter
 """
 
 __author__ = 'VMware, Inc.'
-__copyright__ = 'Copyright 2015, 2017-2019 VMware, Inc.  All rights reserved. -- VMware Confidential'  # pylint: disable=line-too-long
+__copyright__ = 'Copyright 2015, 2017-2019, 2021 VMware, Inc.  All rights reserved. -- VMware Confidential'  # pylint: disable=line-too-long
 
 import json
 import six
@@ -15,57 +15,59 @@ from vmware.vapi.lib.std import (
     make_std_error_def, make_error_value_from_msg_id)
 from vmware.vapi.provider.filter import ApiProviderFilter
 from vmware.vapi.security.authentication_filter import NO_AUTH
+from vmware.vapi.security.vapi_metadata_provider import get_vapi_metadata
 
 # Configure logging
 logger = get_vapi_logger(__name__)
 
-
 def get_metadata(metadata_files):
     """
-    Get the metadata from the json files
+    Get the metadata from the json files and vapi component
 
     :type  metadata_files: :class:`list` of `str`
     :param metadata_files: List of authentication metadata files
     :rtype: :class:`dict` or :class:`None`
     :return: Authorization metadata
     """
+    component_data = {}
     if metadata_files:
         metadata = None
-        component_data = {}
         for metadata_file in metadata_files:
             with open(metadata_file, 'r') as fp:
                 metadata = fp.read()
-            authn_metadata = json.loads(metadata).get('authentication', {})  # pylint: disable=E1103
-            tmp_component_data = authn_metadata.get('component', {})
-            if not tmp_component_data:
-                tmp_component_data = authn_metadata.get('product', {})
+            load_metadata(metadata, component_data)
+    load_metadata(get_vapi_metadata(), component_data)
+    return component_data
 
-            component_name = tmp_component_data.get('name')
-            for key, val in tmp_component_data.items():
-                if key == 'schemes':
-                    # Prefix every scheme name with component name
-                    value = {'%s:%s' % (component_name, k): v
-                             for k, v in val.items()}
-                elif key in ['operations', 'services', 'packages']:
-                    # Prefix every scheme name for packages, services and
-                    # operations with component name
-                    component_value = {}
-                    for k, v in val.items():
-                        if not isinstance(v, list):
-                            v = [v]
-                        component_value.setdefault(k, []).extend(
-                            ['%s:%s' % (component_name, value) for value in v])
-                    value = component_value
-                else:
-                    value = val
+def load_metadata(metadata, component_data):
+    authn_metadata = json.loads(metadata).get('authentication', {})  # pylint: disable=E1103
+    tmp_component_data = authn_metadata.get('component', {})
+    if not tmp_component_data:
+        tmp_component_data = authn_metadata.get('product', {})
 
-                if isinstance(value, dict):
-                    component_data.setdefault(key, {}).update(value)
-                else:
-                    component_data[key] = value
-        return component_data
-    return None
+    component_name = tmp_component_data.get('name')
+    for key, val in tmp_component_data.items():
+        if key == 'schemes':
+            # Prefix every scheme name with component name
+            value = {'%s:%s' % (component_name, k): v
+                     for k, v in val.items()}
+        elif key in ['operations', 'services', 'packages']:
+            # Prefix every scheme name for packages, services and
+            # operations with component name
+            component_value = {}
+            for k, v in val.items():
+                if not isinstance(v, list):
+                    v = [v]
+                component_value.setdefault(k, []).extend(
+                    ['%s:%s' % (component_name, value) for value in v])
+            value = component_value
+        else:
+            value = val
 
+        if isinstance(value, dict):
+            component_data.setdefault(key, {}).update(value)
+        else:
+            component_data[key] = value
 
 class AuthorizationFilter(ApiProviderFilter):
     """
@@ -83,7 +85,7 @@ class AuthorizationFilter(ApiProviderFilter):
         :param provider_config: Provider configuration object
         """
         handler_names = []
-        self._metadata = None
+        metadata_files = None
         self._task_authz_handler = None
         from vmware.vapi.lib.load import dynamic_import
 
@@ -91,7 +93,6 @@ class AuthorizationFilter(ApiProviderFilter):
             # Get the registered AuthN handlers from config file
             (handler_names, metadata_files) = \
                 provider_config.get_authorization_handlers_and_files()
-            self._metadata = get_metadata(metadata_files)
 
             # If tasks are enabled add Tasks Authz Handler as well
             if provider_config.are_tasks_enabled():
@@ -99,6 +100,7 @@ class AuthorizationFilter(ApiProviderFilter):
                     'com.vmware.vapi.task.tasks_impl.TasksAuthzHandler')
                 self._task_authz_handler = handler_constructor()
 
+        self._metadata = get_metadata(metadata_files)
         self._authz_handlers = []
         for handler_name in handler_names:
             # Dynamically load the AuthZ handler
@@ -112,6 +114,8 @@ class AuthorizationFilter(ApiProviderFilter):
             'com.vmware.vapi.std.errors.internal_server_error')
         self._unauthorized_error_def = make_std_error_def(
             'com.vmware.vapi.std.errors.unauthorized')
+        self._operation_not_found_error_def = make_std_error_def(
+            'com.vmware.vapi.std.errors.operation_not_found')
         ApiProviderFilter.__init__(self, next_provider,
                                    [self._internal_server_error_def,
                                     self._unauthorized_error_def])
@@ -256,11 +260,13 @@ class AuthorizationFilter(ApiProviderFilter):
                 service_id)
             return MethodResult(error=error_value)
 
-        if allowed_authn_schemes is None or NO_AUTH in allowed_authn_schemes:
-            is_no_auth_allowed = True
-        else:
-            is_no_auth_allowed = False
+        if not allowed_authn_schemes:
+            error_value = make_error_value_from_msg_id(
+                self._operation_not_found_error_def,
+                'vapi.authentication.metadata.required')
+            return MethodResult(error=error_value)
 
+        is_no_auth_allowed = NO_AUTH in allowed_authn_schemes
         # No valid AuthN info received from AuthN filter for an
         # operation which requires authentication
         if (authn_result is None and not is_no_auth_allowed):
